@@ -82,6 +82,7 @@ public:
     int index;
     Process::Changes changes;
     int elapsedTimeMilliSeconds;
+    int noNewPrivileges;
 };
 
 Process::Process()
@@ -291,6 +292,11 @@ qlonglong Process::startTime() const
     return d->startTime;
 }
 
+int Process::noNewPrivileges() const
+{
+    return d->noNewPrivileges;
+}
+
 int Process::userUsage() const
 {
     return d->userUsage;
@@ -582,6 +588,12 @@ void Process::setStartTime(qlonglong startTime)
     d->startTime = startTime;
 }
 
+void Process::setNoNewPrivileges(int number) {
+    if(d->noNewPrivileges == number) return;
+    d->noNewPrivileges = number;
+    d->changes |= Process::Status;
+}
+
 void Process::setUserUsage(int _userUsage) {
     if(d->userUsage == _userUsage) return;
     d->userUsage = _userUsage;
